package dev.shadowsoffire.apotheosis.adventure.compat;

import mezz.jei.api.recipe.RecipeIngredientRole;
import java.util.Arrays;
import mezz.jei.api.recipe.IFocusGroup;
import mezz.jei.api.gui.builder.IRecipeLayoutBuilder;
import java.util.Iterator;
import com.mojang.blaze3d.vertex.PoseStack;
import net.minecraft.client.gui.Font;
import java.util.List;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.GuiGraphics;
import mezz.jei.api.gui.ingredient.IRecipeSlotsView;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.ingredients.IIngredientType;
import net.minecraft.world.item.ItemStack;
import dev.shadowsoffire.apotheosis.adventure.Adventure;
import net.minecraft.world.level.ItemLike;
import mezz.jei.api.constants.VanillaTypes;
import mezz.jei.api.helpers.IGuiHelper;
import mezz.jei.api.gui.drawable.IDrawable;
import net.minecraft.network.chat.Component;
import net.minecraft.resources.ResourceLocation;
import dev.shadowsoffire.apotheosis.adventure.affix.salvaging.SalvagingRecipe;
import mezz.jei.api.recipe.category.IRecipeCategory;

public class SalvagingCategory implements IRecipeCategory<SalvagingRecipe>
{
    public static final ResourceLocation TEXTURES;
    private final Component title;
    private final IDrawable background;
    private final IDrawable icon;
    
    public SalvagingCategory(final IGuiHelper guiHelper) {
        this.title = (Component)Component.m_237115_("title.apotheosis.salvaging");
        this.background = (IDrawable)guiHelper.drawableBuilder(SalvagingCategory.TEXTURES, 0, 0, 98, 74).addPadding(0, 0, 0, 0).build();
        this.icon = guiHelper.createDrawableIngredient((IIngredientType)VanillaTypes.ITEM_STACK, (Object)new ItemStack((ItemLike)Adventure.Blocks.SALVAGING_TABLE.get()));
    }
    
    public RecipeType<SalvagingRecipe> getRecipeType() {
        return AdventureJEIPlugin.SALVAGING;
    }
    
    public Component getTitle() {
        return this.title;
    }
    
    public IDrawable getBackground() {
        return this.background;
    }
    
    public IDrawable getIcon() {
        return this.icon;
    }
    
    public void draw(final SalvagingRecipe recipe, final IRecipeSlotsView recipeSlotsView, final GuiGraphics gfx, final double mouseX, final double mouseY) {
        final List<SalvagingRecipe.OutputData> outputs = recipe.getOutputs();
        final Font font = Minecraft.m_91087_().f_91062_;
        final PoseStack pose = gfx.m_280168_();
        int idx = 0;
        for (final SalvagingRecipe.OutputData d : outputs) {
            pose.m_85836_();
            pose.m_252880_(0.0f, 0.0f, 200.0f);
            final String text = String.format("%d-%d", d.getMin(), d.getMax());
            final float x = 59 + 18 * (idx % 2) + (16.0f - font.m_92895_(text) * 0.5f);
            final float y = 23.0f + 18 * (idx / 2);
            final float scale = 0.5f;
            pose.m_85841_(scale, scale, 1.0f);
            gfx.m_280488_(font, text, (int)(x / scale), (int)(y / scale), 16777215);
            ++idx;
            pose.m_85849_();
        }
    }
    
    public void setRecipe(final IRecipeLayoutBuilder builder, final SalvagingRecipe recipe, final IFocusGroup focuses) {
        final List<ItemStack> input = Arrays.asList(recipe.getInput().m_43908_());
        builder.addSlot(RecipeIngredientRole.INPUT, 5, 29).addIngredients((IIngredientType)VanillaTypes.ITEM_STACK, (List)input);
        final List<SalvagingRecipe.OutputData> outputs = recipe.getOutputs();
        int idx = 0;
        for (final SalvagingRecipe.OutputData d : outputs) {
            builder.addSlot(RecipeIngredientRole.OUTPUT, 59 + 18 * (idx % 2), 11 + 18 * (idx / 2)).addIngredient((IIngredientType)VanillaTypes.ITEM_STACK, (Object)d.getStack());
            ++idx;
        }
    }
    
    static {
        TEXTURES = new ResourceLocation("apotheosis", "textures/gui/salvage_jei.png");
    }
}
